@@ -6,6 +6,9 @@
 plot.grid.tvp <- function(x, non.interactive=NULL, ...)
   {
 
+oldpar <- par(no.readonly=TRUE) 
+on.exit(par(oldpar))
+
 if (is.null(non.interactive)) 
   {
     non.interactive <- FALSE
@@ -56,7 +59,7 @@ plot3g <- function(x)
 
     for (j in 1:(length(names)))  
       {
-        mypath <- file.path(getwd(), paste("grid_tvp_coef_", j, ".png", sep = ""))
+        mypath <- file.path(tempdir(), paste("grid_tvp_coef_", j, ".png", sep = ""))
         png(filename = mypath, height = height)
         par(xpd = TRUE, fig = c(0, 1, 0, 1), oma = c(2, 1, 1, 1), mar = c(2, 1, 2, 1))
         plot(index(x$models[[1]]$y), rep(NA,length(index(x$models[[1]]$y))), lty=2, type="l", col=col[1], ylim=c(m1[j],m2[j]), 
@@ -75,7 +78,7 @@ plot3g <- function(x)
      img <- list()
      for (i in 1:(length(names)))
       {
-        mypath <- file.path(getwd(), paste("grid_tvp_coef_", i, ".png", sep = ""))
+        mypath <- file.path(tempdir(), paste("grid_tvp_coef_", i, ".png", sep = ""))
         img[[i]] <- readPNG(mypath)
       }
 
@@ -93,7 +96,7 @@ plot3g <- function(x)
         if (non.interactive == FALSE) 
           {
             choices <- c("RMSE", "MAE",
-                         "coefficients - separate plots (files in working directory)" )
+                         "coefficients - separate plots (files in temporary directory)" )
             pick <- menu(choices = paste(" ", choices), title = "\nMake a plot selection (or 0 to exit):")
             switch(pick, plot1g(x), plot2g(x), plot3g(x))
           }
