@@ -4,10 +4,10 @@ print.dma <- function(x, ...)
    cat("Model: ")
    cat(colnames(x$y))
    cat(" ~ ")
-   cat(colnames(x$models))
+   cat(paste(colnames(x$models),collapse=" + "))
    cat("\n")
    cat("\n")
-   print(x$parameters)
+   print(x$parameters,quote=FALSE)
    cat("\n")
    err <- rbind(x$RMSE,x$MAE)
    colnames(err) <- c("model")
@@ -22,4 +22,5 @@ print.dma <- function(x, ...)
    cat("\n")
    cat("variables (incl. constant): ")
    cat(ncol(x$models))
+   cat("\n")
   }
