@@ -6,7 +6,7 @@ summary.altf3 <- function(object, ...)
    cat("\n")
    c <- colMeans(x$coeff.[[1]],na.rm=TRUE)
    c <- round(c,digits=4)
-   print(c)
+   print(c,quote=FALSE)
    
    cat("\n")
    cat("Frequency when p-values for t-test are less than: ")
@@ -29,11 +29,12 @@ summary.altf3 <- function(object, ...)
    vv <- round(vv,digits=2)
    colnames(vv) <- colnames(x$p.val.[[1]])
    rownames(vv) <- c("0.01","0.05","0.10")
-   print(vv)
+   print(vv,quote=FALSE)
    cat("\n")
 
    cat("\n")
    cat("Forecast quality measures: ")
    cat("\n")
-   print(x$summary)
+   print(x$summary,quote=FALSE)
+   cat("\n")
   }
